@@ -92,7 +92,7 @@ public class JavaBridgeRunner extends HttpServer {
      * @return a standalone runner
      * @throws IOException
      */
-    public static synchronized JavaBridgeRunner getInstance(String serverPort) throws IOException {
+    public static synchronized JavaBridgeRunner getRequiredInstance(String serverPort) throws IOException {
 	if(runner!=null) return runner;
 	runner = new JavaBridgeRunner(serverPort);
 	return runner;
@@ -101,7 +101,7 @@ public class JavaBridgeRunner extends HttpServer {
      * Return a instance.
      * @return a standalone runner
      */
-    public static synchronized JavaBridgeRunner getRequiredInstance(String serverPort) {
+    public static synchronized JavaBridgeRunner getInstance(String serverPort) {
 	if(runner!=null) return runner;
 	try {
 	    runner = new JavaBridgeRunner(serverPort);
@@ -115,7 +115,7 @@ public class JavaBridgeRunner extends HttpServer {
      * @return a standalone runner
      * @throws IOException
      */
-    public static synchronized JavaBridgeRunner getInstance() throws IOException {
+    public static synchronized JavaBridgeRunner getRequiredInstance() throws IOException {
 	if(runner!=null) return runner;
 	runner = new JavaBridgeRunner();
 	return runner;
@@ -127,34 +127,19 @@ public class JavaBridgeRunner extends HttpServer {
      * @return a standalone runner
      * @throws IOException
      */
-    public static synchronized JavaBridgeRunner getStandaloneInstance(String serverPort) throws IOException {
+    private static synchronized JavaBridgeRunner getRequiredStandaloneInstance(String serverPort) throws IOException {
 	if(runner!=null) return runner;
 	runner = new JavaBridgeRunner(serverPort);
 	runner.isStandalone = true;
 	return runner;
     }
-    /**
-     * Return a standalone instance. 
-     * It sets a flag which indicates that the runner will be used as a standalone component outside of the Servlet environment.
-     * @return a standalone runner
-     */
-    public static synchronized JavaBridgeRunner getRequiredStandaloneInstance(String serverPort) {
-	if(runner!=null) return runner;
-	try {
-	    runner = new JavaBridgeRunner(serverPort);
-        } catch (IOException e) {
-	    Util.printStackTrace(e);
-        }
-	runner.isStandalone = true;
-	return runner;
-    }
     /**
      * Return a standalone instance. 
      * It sets a flag which indicates that the runner will be used as a standalone component outside of the Servlet environment.
      * @return a standalone runner
      * @throws IOException
      */
-    public static synchronized JavaBridgeRunner getStandaloneInstance() throws IOException {
+    public static synchronized JavaBridgeRunner getRequiredStandaloneInstance() throws IOException {
 	if(runner!=null) return runner;
 	runner = new JavaBridgeRunner();
 	runner.isStandalone = true;
@@ -221,7 +206,7 @@ public class JavaBridgeRunner extends HttpServer {
                 ctxServer.start(channelName);
         	    if(bridge.logLevel>3) 
         		bridge.logDebug("waiting for context: " +ctx.getId());
-        	    try { ctx.waitFor(); } catch (InterruptedException e) { Util.printStackTrace(e); }
+        	    try { ctx.waitFor(Util.MAX_WAIT); } catch (InterruptedException e) { Util.printStackTrace(e); }
         	}
         else {
             ctx.destroy();
@@ -456,7 +441,7 @@ public class JavaBridgeRunner extends HttpServer {
 		params = name.substring(idx+1);
 		name = name.substring(0, idx);
 	    }
-	    File f = Util.getCanonicalWindowsFile(name);
+	    File f = Standalone.getCanonicalWindowsFile(name);
 	    if(f==null || !f.exists()) f = new File(Util.HOME_DIR, name);
 	    if(f==null || !f.exists()) return;
 	    if(f.isHidden()) return;
@@ -526,6 +511,15 @@ public class JavaBridgeRunner extends HttpServer {
     public boolean isStandalone() {
 	return isStandalone;
     }
+    
+    /**
+     * Wait for the runner to finish
+     * @throws InterruptedException 
+     */
+    public void waitFor () throws InterruptedException {
+        runner.httpServer.join();
+    }
+    
     /**
      * For internal tests only.
      * @throws InterruptedException 
@@ -537,7 +531,7 @@ public class JavaBridgeRunner extends HttpServer {
 	     if(s.length>0 && s[0]!=null) serverPort = (Util.JAVABRIDGE_PROMISCUOUS ? "INET:" :"INET_LOCAL:") +s[0];
 	 }
 	 Util.logMessage("JavaBridgeRunner started on port " + serverPort);
-	 JavaBridgeRunner r = getStandaloneInstance(serverPort);
+	 JavaBridgeRunner r = getRequiredStandaloneInstance(serverPort);
 	 r.httpServer.join();
 	 r.destroy();
     }
