@@ -61,6 +61,8 @@ public final class Util {
     // method to load a CLR assembly
     static Method loadMethod, loadFileMethod;
     static Class CLRAssembly;
+    /** how long shall we wait for a remote client to terminate? */
+    public static final int MAX_WAIT = 30000;
     
     private Util() {}
     
@@ -127,12 +129,12 @@ public final class Util {
 		}
 	}
     }
-    
-    /** The default HTTP port for management clients */
-    public static final int HTTP_PORT_BASE = 8080;
-    /** The default Port for Mono and .NET clients */
-    public static int EXTENSION_TCP_PORT_BASE;
 
+    /** 
+     * The default PHP arguments
+     */
+    public static final String PHP_ARGS[] = new String[] {"-d", "allow_url_include=On", "-d", "display_errors=Off", "-d", "log_errors=On"};
+    
     /**
      * The default CGI locations: <code>"/usr/bin/php-cgi"</code>, <code>"c:/php/php-cgi.exe</code>
      */
@@ -177,12 +179,6 @@ public final class Util {
     /** Set to true if the VM is gcj, false otherwise */
     public static final boolean IS_GNU_JAVA = checkVM();
 
-    /** 
-     * The TCP socket name. Default is 9267.
-     * @see System property <code>php.java.bridge.tcp_socketname</code>
-     */
-    public static String TCP_SOCKETNAME;
-
     /**
      * The name of the extension, usually "JavaBridge" or "MonoBridge"
      */
@@ -275,13 +271,8 @@ public final class Util {
     	    JAVABRIDGE_PROMISCUOUS = false;
 	    JAVABRIDGE_PROMISCUOUS = System.getProperty("php.java.bridge.promiscuous", "false").toLowerCase().equals("true");	    
 	} catch (Exception e) {/*ignore*/}
-	try {
-    	    IS_MONO=false;
-    	    Util.CLRAssembly = Class.forName("cli.System.Reflection.Assembly");
-    	    Util.loadFileMethod = Util.CLRAssembly.getMethod("LoadFile", new Class[] {String.class});
-    	    Util.loadMethod = Util.CLRAssembly.getMethod("Load", new Class[] {String.class});
-    	    IS_MONO=true;
-    	} catch (Exception e) {/*ignore*/}
+
+	IS_MONO = Standalone.checkMono();
 
     	Properties p = new Properties();
 	try {
@@ -296,13 +287,6 @@ public final class Util {
 	} catch (Throwable t) {
 	    //t.printStackTrace();
 	};
-	if (IS_MONO) {
-	    	EXTENSION_TCP_PORT_BASE = 9167;
-		TCP_SOCKETNAME = String.valueOf(Integer.parseInt(getProperty(p, "TCP_SOCKETNAME", "9267"))-100);
-	} else {
-	    	EXTENSION_TCP_PORT_BASE = 9267;
-		TCP_SOCKETNAME = getProperty(p, "TCP_SOCKETNAME", String.valueOf(EXTENSION_TCP_PORT_BASE));
-	}
 	EXTENSION_NAME = getProperty(p, "EXTENSION_DISPLAY_NAME", "JavaBridge");
 	PHP_EXEC = getProperty(p, "PHP_EXEC", null);
 	try {
@@ -624,7 +608,7 @@ public final class Util {
      * @author jostb
      * @see Util#parseBody(byte[], InputStream, OutputStream, HeaderParser)
      */
-    public static class HeaderParser {protected void parseHeader(String header) {/*template*/}}
+    public static class HeaderParser {public void parseHeader(String header) {/*template*/}}
     /**
      * Discards all header fields from a HTTP connection and write the body to the OutputStream
      * @param buf A buffer, for example new byte[BUF_SIZE]
@@ -704,18 +688,6 @@ public final class Util {
 	} catch (UnknownHostException e) {/*ignore*/}
 	return addr;
     }
-    /**
-     * Returns the canonical windows file. For example c:\program files instead of c:\programme
-     * @param path The path, may be an empty string.
-     * @return the canonical file.
-     */
-    public static File getCanonicalWindowsFile (String path) {
-	    try {
-	        return new File(path).getCanonicalFile();
-        } catch (IOException e) {
-	        return new File(path);
-        }
-    }
     /**
      * Checks if the cgi binary buf-&lt;os.arch&gt;-&lt;os.name&gt;.sh or buf-&lt;os.arch&gt;-&lt;os.name&gt;.exe or buf-&lt;os.arch&gt;-&lt;os.name&gt; exists.
      * @param buf The base name, e.g.: /opt/tomcat/webapps/JavaBridge/WEB-INF/cgi/php-cgi
@@ -751,7 +723,7 @@ public final class Util {
      */
     public static String checkError(String s) {
         // Is there a better way to check for a fatal error?
-        return s.indexOf("PHP Fatal error:")>-1 ? s : null;
+        return s.indexOf("PHP Fatal error:")>-1 || s.indexOf("PHP Parse error:")>-1 ? s : null;
     }
 
     /** 
@@ -890,19 +862,28 @@ public final class Util {
 	 * @throws IOException
 	 * @see Util#checkCgiBinary(StringBuffer)
 	 */	  
-        public static Process start(String[] args, File homeDir, Map env, boolean tryOtherLocations, boolean preferSystemPhp) throws IOException {
+        public static Process start(String[] args, File homeDir, Map env, boolean tryOtherLocations, boolean preferSystemPhp, OutputStream err) throws IOException {
             Process proc = new Process(args, homeDir, env, tryOtherLocations, preferSystemPhp);
             proc.start();
             return proc;
         }
 
+        /** A generic PHP exception */
         public static class PhpException extends Exception {
 	    private static final long serialVersionUID = 767047598257671018L;
 	    private String errorString;
+	    /** 
+	     * Create a PHP exception 
+	     * @param errorString the PHP error string 
+	     */
 	    public PhpException(String errorString) {
 		super(errorString);
 		this.errorString = errorString;
 	    }
+	    /** 
+	     * Return the error string
+	     * @return the PHP error string
+	     */
 	    public String getError() {
 		return errorString;
 	    }
@@ -971,9 +952,7 @@ public final class Util {
 	    (new Util.Thread("CGIErrorReader") {public void run() {readErrorStream();}}).start();
 	}
         /**
-         * Returns s if s contains "PHP Fatal error:";
-         * @param s The error string
-         * @return The fatal error or null
+         * Throw a PhpException when a fatal error occured.
          */	
 	public void checkError() throws PhpException {
 	    String errorString = error==null?null:Util.checkError(error.toString());
@@ -1030,7 +1009,7 @@ public final class Util {
      * @return The thread context class loader.
       */
     public static ClassLoader getContextClassLoader() {
-          return JavaBridgeClassLoader.getDefaultClassLoader(JavaBridgeClassLoader.getContextClassLoader());
+          return JavaBridgeClassLoader.getContextClassLoader();
     }
     /** Redirect System.out and System.err to the configured logFile or System.err.
      * System.out is always redirected, either to the logFile or to System.err.
@@ -1318,4 +1297,20 @@ public final class Util {
 	    return false;
 	}
     }
+    /**
+     * Return args + PHP_ARGS
+     * @param args The prefix
+     * @return args with PHP_ARGS appended
+     */
+    public static final String[] getPhpArgs(String[] args) {
+	String[] allArgs = new String[args.length+PHP_ARGS.length];
+	int i=0;
+	for(i=0; i<args.length; i++) {
+	    allArgs[i]=args[i];
+	}
+	for(int j=0; j<PHP_ARGS.length; j++) {
+	    allArgs[i++]=PHP_ARGS[j];
+	}
+	return allArgs;
+    }
 }
