@@ -268,7 +268,7 @@ public class PhpCGIServlet extends FastCGIServlet {
 	    OutputStream out = null;
 
 	    try {
-        	proc = Util.ProcessWithErrorHandler.start(new String[]{php, "-d", "allow_url_include=On"}, wd, env, phpTryOtherLocations, preferSystemPhp, natErr);
+        	proc = Util.ProcessWithErrorHandler.start(Util.getPhpArgs(new String[]{php}), wd, env, phpTryOtherLocations, preferSystemPhp, natErr);
 
         	byte[] buf = new byte[BUF_SIZE];// headers cannot be larger than this value!
 
